@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "groupmanager.h"
 
@@ -153,7 +138,7 @@ GroupManager::~GroupManager()
 Group *GroupManager::newGroup(const QString &name)
 {
     if (groups.find(name))
-        return 0;
+        return nullptr;
 
     TorrentGroup *g = new TorrentGroup(name);
     connect(g, &TorrentGroup::torrentAdded, this, &GroupManager::customGroupChanged);
@@ -231,7 +216,7 @@ void GroupManager::loadGroups()
         return;
     }
 
-    bt::BNode *n = 0;
+    bt::BNode *n = nullptr;
     try {
         Uint32 fs = bt::FileSize(fn);
         QByteArray data(fs, 0);
